# -------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for
# license information.
# --------------------------------------------------------------------------

STORAGE_ACCOUNT_NAME = "fakename"
STORAGE_ACCOUNT_KEY = "fakekey"

SECONDARY_STORAGE_ACCOUNT_NAME = "fakename"
SECONDARY_STORAGE_ACCOUNT_KEY = "fakekey"
BLOB_STORAGE_ACCOUNT_NAME = "fakename"
BLOB_STORAGE_ACCOUNT_KEY = "fakekey"
VERSIONED_STORAGE_ACCOUNT_NAME = "fakename"
VERSIONED_STORAGE_ACCOUNT_KEY = "fakekey"
PREMIUM_STORAGE_ACCOUNT_NAME = "fakename"
PREMIUM_STORAGE_ACCOUNT_KEY = "fakekey"
SOFT_DELETE_STORAGE_ACCOUNT_NAME = "fakename"
SOFT_DELETE_STORAGE_ACCOUNT_KEY = "fakekey"
STORAGE_RESOURCE_GROUP_NAME = "fakename"

ACCOUNT_URL_SUFFIX = 'core.windows.net'
RUN_IN_LIVE = "False"
SKIP_LIVE_RECORDING = "True"

PROTOCOL = "https"
